Skip to contents

Filter low variance features

Usage

removeLowVariance(sce, threshold = 0, robust = FALSE)

Arguments

sce

SingleCellExperiment object

threshold

Keep features that have larger variance than this threshold

robust

If true use median absolute deviation, otherwise use variance

Value

SingleCellExperiment object

Examples

set.seed(23)
cell_file <- generate_data()
sce <- loadData(cell_file)
sce <- removeLowVariance(sce)