Remove row and column effect using the median polish procedure
Source:R/cellpaintr.R
removeRowColEffect.RdRemove row and column effect using the median polish procedure
Arguments
- sce
SingleCellExperimentobject- assay_type
A string specifying the assay
Value
SingleCellExperiment object
Examples
set.seed(23)
cell_file <- generate_data()
sce <- loadData(cell_file)
sce <- transformScale(sce)
row <- substr(sce$Well, 1, 1)
row <- factor(row, levels = LETTERS[1:length(unique(row))])
col <- substr(sce$Well, 2, 3)
col <- factor(as.numeric(col))
sce$Row <- row
sce$Col <- col
sce <- removeRowColEffect(sce)